/**
 * Copyright (c) 2016-2018 Thales Global Services S.A.S.
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *   Abel Hegedus, Tamas Borbas, Peter Lunk (IncQuery Labs Ltd.) - initial API and implementation
 */
package org.eclipse.emf.diffmerge.patch.ui.handlers;

import java.util.Arrays;
import org.eclipse.core.commands.AbstractHandler;
import org.eclipse.core.commands.ExecutionEvent;
import org.eclipse.core.commands.ExecutionException;
import org.eclipse.emf.diffmerge.patch.ui.utils.DialogFactory;
import org.eclipse.emf.diffmerge.patch.ui.wizards.ModelpatchApplicationWizard;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.ecore.resource.Resource;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.jface.wizard.WizardDialog;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.ui.handlers.HandlerUtil;
import org.eclipse.xtext.xbase.lib.Exceptions;

@SuppressWarnings("all")
public class ModelpatchApplicationHandler extends AbstractHandler {
  public static final String ID = "org.eclipse.emf.diffmerge.patch";
  
  private Shell shell;
  
  @Override
  public Object execute(final ExecutionEvent event) throws ExecutionException {
    try {
      this.shell = HandlerUtil.getActiveShell(event);
      ISelection _currentSelection = HandlerUtil.getCurrentSelection(event);
      this.executePatch(((IStructuredSelection) _currentSelection));
    } catch (final Throwable _t) {
      if (_t instanceof Exception) {
        final Exception ex = (Exception)_t;
        final DialogFactory factory = new DialogFactory(this.shell);
        factory.openErrorDialog("Modelpatch Application Problem", "Patch cannot be applied!", ex, ModelpatchApplicationHandler.ID);
        ex.printStackTrace();
      } else {
        throw Exceptions.sneakyThrow(_t);
      }
    }
    return null;
  }
  
  private void _executePatch(final IStructuredSelection strucSelection) {
    this.executePatch(strucSelection.getFirstElement());
  }
  
  private void _executePatch(final EObject eobj) {
    this.executePatch(eobj.eResource());
  }
  
  private void _executePatch(final Resource resource) {
    ModelpatchApplicationWizard _modelpatchApplicationWizard = new ModelpatchApplicationWizard(resource);
    final WizardDialog wizard = new WizardDialog(this.shell, _modelpatchApplicationWizard);
    wizard.open();
  }
  
  private void executePatch(final Object eobj) {
    if (eobj instanceof EObject) {
      _executePatch((EObject)eobj);
      return;
    } else if (eobj instanceof Resource) {
      _executePatch((Resource)eobj);
      return;
    } else if (eobj instanceof IStructuredSelection) {
      _executePatch((IStructuredSelection)eobj);
      return;
    } else {
      throw new IllegalArgumentException("Unhandled parameter types: " +
        Arrays.<Object>asList(eobj).toString());
    }
  }
}
