/**
 * Copyright (c) 2016-2018 Thales Global Services S.A.S.
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *   Abel Hegedus, Tamas Borbas, Balazs Grill, Peter Lunk, Daniel Segesdi (IncQuery Labs Ltd.) - initial API and implementation
 */
package org.eclipse.emf.diffmerge.patch.ui.utils;

import com.google.common.base.Objects;
import java.util.Arrays;
import java.util.List;
import org.eclipse.emf.diffmerge.patch.api.ModelPatch;
import org.eclipse.emf.diffmerge.patch.api.ModelPatchEntry;
import org.eclipse.jface.viewers.ITreeContentProvider;
import org.eclipse.jface.viewers.Viewer;
import org.eclipse.xtext.xbase.lib.CollectionLiterals;
import org.eclipse.xtext.xbase.lib.Conversions;

@SuppressWarnings("all")
public class ModelPatchContentProvider implements ITreeContentProvider {
  @Override
  public void dispose() {
  }
  
  @Override
  public void inputChanged(final Viewer viewer, final Object oldInput, final Object newInput) {
  }
  
  @Override
  public Object[] getElements(final Object inputElement) {
    boolean _equals = Objects.equal(inputElement, null);
    if (_equals) {
      return ((Object[])Conversions.unwrapArray(CollectionLiterals.<Object>newArrayList(), Object.class));
    }
    return ((Object[])Conversions.unwrapArray(this.getAllElements(inputElement), Object.class));
  }
  
  @Override
  public Object[] getChildren(final Object parentElement) {
    return ((Object[])Conversions.unwrapArray(this.getAllElements(parentElement), Object.class));
  }
  
  @Override
  public Object getParent(final Object element) {
    return null;
  }
  
  @Override
  public boolean hasChildren(final Object element) {
    int _size = this.getAllElements(element).size();
    return (_size > 0);
  }
  
  private List<?> _getAllElements(final Object patch) {
    return CollectionLiterals.<Object>newArrayList();
  }
  
  private List<?> _getAllElements(final ModelPatch patch) {
    return patch.getEntries();
  }
  
  private List<?> _getAllElements(final ModelPatchEntry ee) {
    return CollectionLiterals.<Object>newArrayList();
  }
  
  private List<?> getAllElements(final Object patch) {
    if (patch instanceof ModelPatch) {
      return _getAllElements((ModelPatch)patch);
    } else if (patch instanceof ModelPatchEntry) {
      return _getAllElements((ModelPatchEntry)patch);
    } else if (patch != null) {
      return _getAllElements(patch);
    } else {
      throw new IllegalArgumentException("Unhandled parameter types: " +
        Arrays.<Object>asList(patch).toString());
    }
  }
}
